/* 
*   NAME
*   Copyright (c) 2021 AUTHOR.
*/

export * from "./CLASS_NAMEPredictor"